@@ -186,22 +186,31 @@ MyPropertySheet::MyPropertySheet (
 	    generalPanel,
 	    wxID_ANY );
 
+    languageBox->Insert ( _T ( "Catalan" ), INDEX_CATALAN );
 	languageBox->Insert ( _T ( "Chinese Simplified" ), INDEX_CHINESE_SIMPLIFIED );
 	languageBox->Insert ( _T ( "Chinese Traditional" ), INDEX_CHINESE_TRADITIONAL );
+	languageBox->Insert ( _T ( "Dutch" ), INDEX_DUTCH );
 	languageBox->Insert ( _T ( "English (US)" ), INDEX_ENGLISH_US );
 	languageBox->Insert ( _T ( "French" ), INDEX_FRENCH );
 	languageBox->Insert ( _T ( "German" ), INDEX_GERMAN );
 	languageBox->Insert ( _T ( "Italian" ), INDEX_ITALIAN );
 	languageBox->Insert ( _T ( "Russian" ), INDEX_RUSSIAN );
 	languageBox->Insert ( _T ( "Slovak" ), INDEX_SLOVAK );
+	languageBox->Insert ( _T ( "Spanish" ), INDEX_SPANISH );
 	languageBox->Insert ( _T ( "Swedish" ), INDEX_SWEDISH );
 	languageBox->Insert ( _T ( "Ukrainian" ), INDEX_UKRAINIAN );
 
 	switch ( lang )
 	{
+        case wxLANGUAGE_CATALAN:
+            languageBox->SetSelection ( INDEX_CATALAN );
+            break;
 		case wxLANGUAGE_GERMAN:
 			languageBox->SetSelection ( INDEX_GERMAN );
 			break;
+		case wxLANGUAGE_DUTCH:
+            languageBox->SetSelection ( INDEX_DUTCH );
+            break;
 		case wxLANGUAGE_FRENCH:
 			languageBox->SetSelection ( INDEX_FRENCH );
 			break;
@@ -226,6 +235,9 @@ MyPropertySheet::MyPropertySheet (
 		case wxLANGUAGE_UKRAINIAN:
 			languageBox->SetSelection ( INDEX_UKRAINIAN );
 			break;
+		case wxLANGUAGE_SPANISH:
+             languageBox->SetSelection ( INDEX_SPANISH );
+             break;
 		default:
 			languageBox->SetSelection ( INDEX_ENGLISH_US );
 			break;
@@ -333,7 +345,13 @@ void MyPropertySheet::OnOk ( wxCommandEvent& e )
 	int languageChoice = languageBox->GetSelection();
 	switch ( languageChoice )
 	{
-		case INDEX_ITALIAN:
+        case INDEX_CATALAN:
+            lang = wxLANGUAGE_CATALAN;
+            break;
+		case INDEX_DUTCH:
+            lang = wxLANGUAGE_DUTCH;
+            break;
+        case INDEX_ITALIAN:
 			lang = wxLANGUAGE_ITALIAN;
 			break;
 		case INDEX_GERMAN:
@@ -354,6 +372,9 @@ void MyPropertySheet::OnOk ( wxCommandEvent& e )
 		case INDEX_SLOVAK:
 			lang = wxLANGUAGE_SLOVAK;
 			break;
+		case INDEX_SPANISH:
+             lang = wxLANGUAGE_SPANISH;
+             break;
 		case INDEX_SWEDISH:
 			lang = wxLANGUAGE_SWEDISH;
 			break;
