@@ -34,14 +34,17 @@ enum
 
 enum langIndex
 {
-	INDEX_CHINESE_SIMPLIFIED = 0,
+    INDEX_CATALAN = 0,
+	INDEX_CHINESE_SIMPLIFIED,
 	INDEX_CHINESE_TRADITIONAL,
+	INDEX_DUTCH,
 	INDEX_ENGLISH_US,
 	INDEX_FRENCH,
 	INDEX_GERMAN,
 	INDEX_ITALIAN,
 	INDEX_RUSSIAN,
 	INDEX_SLOVAK,
+	INDEX_SPANISH,
 	INDEX_SWEDISH,
 	INDEX_UKRAINIAN
 };
