@@ -31,7 +31,7 @@
 
 using namespace xercesc;
 
-WrapXerces::WrapXerces( std::string catalogPath )
+WrapXerces::WrapXerces( std::string catalogPath, std::string catalogUtilityPath )
 {
 	try
 	{
@@ -42,7 +42,7 @@ WrapXerces::WrapXerces( std::string catalogPath )
 		throw std::runtime_error ( "Cannot initialize Xerces" );
 	}
 	errorPosition = std::make_pair ( 1, 1 );
-	catalogResolver = new XercesCatalogResolver();
+	catalogResolver = new XercesCatalogResolver( catalogPath, catalogUtilityPath );
 }
 
 WrapXerces::~WrapXerces()
