@@ -32,7 +32,8 @@ using namespace xercesc;
 class WrapXerces
 {
 	public:
-		WrapXerces( std::string catalogPath = "" );
+		WrapXerces( std::string catalogPath = "",
+                    std::string catalogUtilityPath = "" );
 		~WrapXerces();
 		bool validate ( const std::string& fileName );
 		bool validateMemory ( const char *buffer, const char *system, unsigned len );
