@@ -41,6 +41,7 @@
 #include <wx/snglinst.h>
 #include <wx/ipc.h>
 #include <wx/intl.h>
+#include <wx/fileconf.h>
 #include <utility>
 #include <string>
 #include <set>
@@ -156,6 +157,7 @@ enum
 	ID_VALIDATE_PRESET7,
 	ID_VALIDATE_PRESET8,
 	ID_VALIDATE_PRESET9,
+	ID_EXPORT,
 	ID_EXPORT_MSWORD,
 	// icon constants
 	CONST_WARNING,
@@ -184,7 +186,7 @@ class MyApp : public wxApp
 		MyClientConnection *connection;
 		bool singleInstanceCheck;
 		int lang;
-		std::auto_ptr<wxConfig> config;
+		std::auto_ptr<wxFileConfig> config;
 };
 
 // forward declarations
@@ -203,7 +205,7 @@ class MyFrame : public wxFrame
 	public:
 		MyFrame (
 		    const wxString& title,
-		    wxConfig *configParameter,
+		    wxFileConfig *configParameter,
 		    wxLocale& locale,
 		    bool singleInstanceCheck,
 		    int langParameter );
@@ -233,6 +235,7 @@ class MyFrame : public wxFrame
 		void OnFontMedium ( wxCommandEvent& event );
 		void OnFontLarger ( wxCommandEvent& event );
 		void OnImportMSWord ( wxCommandEvent& event );
+		void OnExport ( wxCommandEvent& event );
 		void OnInsertChild ( wxCommandEvent& event );
 		void OnInsertSibling ( wxCommandEvent& event );
 		void OnInsertTwin ( wxCommandEvent& event );
@@ -337,10 +340,11 @@ class MyFrame : public wxFrame
 		bool isOpen ( const wxString& fileName );
 		bool activateTab ( const wxString& fileName );
 		void reloadTab();
+		void addToFileQueue ( wxString& fileName );
 	private:
 		wxAuiManager manager;
-		wxConfig *config; // owned by MyApp
-		wxLocale& myLocale;
+		wxFileConfig *config; // owned by MyApp
+        wxLocale& myLocale;
 		bool singleInstanceCheck;
 		int lang, lastPos;
 		wxLogNull logTarget;
@@ -366,14 +370,14 @@ class MyFrame : public wxFrame
 		MyHtmlPane *htmlReport;
 
 		std::string catalogPath, catalogUtilityPath, xslDtdPath, rssDtdPath, lzxDtdPath, xtmDtdPath,
-		xliffDtdPath;
+		xliffDtdPath, aspellDataPath, aspellDictPath;
 		std::pair<int, int> controlCoordinates;
 		std::map<std::string, std::map<std::string, std::set<std::string> > >
 		promptMap;
 		std::map<int, wxString> validationPresetMap;
 		std::set<wxString> openFileSet;
 		std::set<wxString> openLargeFileSet;
-		std::vector<wxString> tempFileVector;
+		std::vector<wxString> tempFileVector, fileQueue;
 		int documentCount,
 		framePosX,
 		framePosY,
@@ -385,33 +389,36 @@ class MyFrame : public wxFrame
 		wxPoint stylePosition, aboutPosition;
 		wxSize styleSize;
 		wxString applicationDir,
-		ruleSetPreset,
-		dictionaryPreset,
-		filterPreset,
-		ruleSetDir,
-		filterDir,
-		binDir,
-		templateDir,
-		helpDir,
-		rngDir,
-		htmlDir,
-		pngDir,
-		xpathExpression,
-		lastDtdPublic,
-		lastDtdSystem,
-		lastSchema,
-		lastSchemaNamespace,
-		lastXslStylesheet,
-		lastSchemaNamespaceAux,
-		lastRelaxNGSchema,
-		lastDtdPublicAux,
-		openTabsOnClose,
-		browserCommand,
-		layout,
-		defaultLayout,
-		lastParent,
-		lastGrandparent,
-		commandString;
+		  ruleSetPreset,
+		  dictionaryPreset,
+		  filterPreset,
+		  ruleSetDir,
+		  filterDir,
+		  binDir,
+		  templateDir,
+		  helpDir,
+		  rngDir,
+		  htmlDir,
+		  pngDir,
+		  daisyDir,
+		  xpathExpression,
+		  lastDtdPublic,
+		  lastDtdSystem,
+		  lastSchema,
+		  lastSchemaNamespace,
+		  lastXslStylesheet,
+		  lastSchemaNamespaceAux,
+		  lastRelaxNGSchema,
+		  lastDtdPublicAux,
+		  openTabsOnClose,
+		  browserCommand,
+		  layout,
+		  defaultLayout,
+		  lastParent,
+		  lastGrandparent,
+		  commandString,
+          exportStylesheet,
+          exportFolder;
 		bool globalReplaceAllDocuments,
 		toolbarVisible,
 		protectTags,
@@ -435,7 +442,9 @@ class MyFrame : public wxFrame
 		restoreFocusToNotebook,
 		showFullPathOnFrame,
 		findRegex,
-		commandSync;
+		commandSync,
+        exportQuiet,
+        exportMp3Album;
 		wxBitmap newBitmap,
 		new16Bitmap,
 		openBitmap,
@@ -513,4 +522,3 @@ class MyFrame : public wxFrame
 };
 
 #endif
-
